#include <WScom.h>
#include <WSCfunctionList.h>
#include <WSCbase.h>

/**/

#include "Common.h"

/**/

//----------------------------------------------------------
//Function for the event procedure
//----------------------------------------------------------
void CnfWinInit(WSCbase* object){
  //do something...

	/* Set label */

	Cnfvlab_Name->setProperty( WSNlabelString, MesLabelName );
	Cnfvlab_Url->setProperty( WSNlabelString, MesLabelUrl );
	Cnfvtog_Download->setProperty( WSNlabelString, MesLabelDownload );
	Cnfvlab_Encoding->setProperty( WSNlabelString, MesLabelEncoding );
	Cnfvlab_SkipArt->setProperty( WSNlabelString, MesLabelSkipArt );

	Cnfvbtn_DeleteBtn->setProperty( WSNlabelString, MesLabelDelete );
	Cnfvbtn_UpdateBtn->setProperty( WSNlabelString, MesLabelUpdate );
	Cnfvbtn_NewBtn->setProperty( WSNlabelString, MesLabelNew );

	Cnfvlab_OrderTitle->setProperty( WSNlabelString, MesLabelOrder );
	Cnfvbtn_UpBtn->setProperty( WSNlabelString, MesLabelUp );
	Cnfvbtn_DownBtn->setProperty( WSNlabelString, MesLabelDown );
	Cnfvbtn_TopBtn->setProperty( WSNlabelString, MesLabelTop );
	Cnfvbtn_BottomBtn->setProperty( WSNlabelString, MesLabelBottom );

	/* Set data */

	Cnfcomb_Encoding->setProperty( WSNmenuItems, GetEncodingList() );

	Cnfcomb_NameList->setProperty( WSNmenuItems, gUrl.GetList() );
	Cnfcomb_NameList->setProperty( WSNlabelString,
		Maicomb_NameList->getProperty( WSNlabelString ) );

	Cnfcomb_NameList->execProcedure( "CnfNameListSelect" );
}

static WSCfunctionRegister  op("CnfWinInit",(void*)CnfWinInit);
